@@ -53,7 +53,7 @@ class RecentEmojiModel : public AbstractEmojiModel
 {
     Q_OBJECT
     QML_ELEMENT
-    Q_PROPERTY(int count READ rowCount CONSTANT)
+    Q_PROPERTY(int count READ rowCount NOTIFY countChanged)
 public:
     RecentEmojiModel();
 
@@ -61,6 +61,8 @@ public:
 
     Q_INVOKABLE void clearHistory();
 
+    Q_SIGNAL void countChanged();
+
 private:
     void refresh();
 
