@@ -271,10 +271,10 @@ QHash<int, QByteArray> SortedActivitiesModel::roleNames() const
 
     auto roleNames = sourceModel()->roleNames();
 
-    roleNames[LastTimeUsed] = "lastTimeUsed";
-    roleNames[LastTimeUsedString] = "lastTimeUsedString";
-    roleNames[WindowCount] = "windowCount";
-    roleNames[HasWindows] = "hasWindows";
+    roleNames[LastTimeUsed] = QByteArrayLiteral("lastTimeUsed");
+    roleNames[LastTimeUsedString] = QByteArrayLiteral("lastTimeUsedString");
+    roleNames[WindowCount] = QByteArrayLiteral("windowCount");
+    roleNames[HasWindows] = QByteArrayLiteral("hasWindows");
 
     return roleNames;
 }
@@ -468,3 +468,5 @@ void SortedActivitiesModel::rowChanged(int row, const QList<int> &roles)
         return;
     Q_EMIT dataChanged(index(row, 0), index(row, 0), roles);
 }
+
+#include "moc_sortedactivitiesmodel.cpp"
